pub struct CodeModeTool { /* private fields */ }Expand description
Adapter that exposes the UTCP CodeMode runtime as a tool in the agent catalog.
This allows agents to execute code snippets via the codemode.run_code tool.
Implementations
Sourceimpl CodeModeTool
impl CodeModeTool
pub fn new(engine: Arc<CodeModeUtcp>) -> Self